# invana-engine

GraphQL API and Insights engine for Apache TinkerPop supported graph databases.


**Note: Under active development.** 

[![Apache license](https://img.shields.io/badge/license-Apache-blue.svg)](https://github.com/invanalabs/invana-engine/blob/master/LICENSE) 
[![Build Status](https://travis-ci.org/invanalabs/invana-engine.svg?branch=master)](https://travis-ci.org/invanalabs/invana-engine)
[![Commit Activity](https://img.shields.io/github/commit-activity/m/invanalabs/invana-engine)](https://github.com/invanalabs/invana-engine/commits)
[![codecov](https://codecov.io/gh/invanalabs/invana-engine/branch/master/graph/badge.svg)](https://codecov.io/gh/invanalabs/invana-engine)


Checkout [Documentation](https://docs.invana.io) for info on how to install and use Invana Engine. 



## License 

Apache License 2.0
